## Copyright (C) 2002 by Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
##
## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {} scloseall (@var{connections})
## Deprecated function, calls @code{sclose (connections)}, which should
## be called directly.
##
## @seealso {sclose}
## @end deftypefn

function scloseall (connections)

  persistent warned = false;
  if (! warned)
    warned = true;
    warning ("Octave:deprecated-function",
             "scloseall is deprecated, please use sclose directly.");
  endif

  sclose (connections);

endfunction
